@@ -1,4 +1,4 @@
-from botty_core import CompositeHandler, app
+from botty_core import CompositeHandler
 
 from .buttons import CallbackButton, UrlButton
 from .handlers import (
@@ -12,6 +12,7 @@ from .handlers import (
     UpdateHandler,
 )
 from .keyboards import InlineButtons, InlineKeyboard
+from .loader import app
 from .texts import Texts
 
 __all__ = [
