@@ -1,10 +1,12 @@
+from collections.abc import Mapping
+
 from botty.buttons import CallbackButton
 
 from .query import QueryHandler
 
 
 class InlineMenuHandler(QueryHandler):
-    def __init__(self, buttons: dict[CallbackButton, QueryHandler]) -> None:
+    def __init__(self, buttons: Mapping[CallbackButton, QueryHandler]) -> None:
         self.buttons = buttons
         on_button = [b.text for b in buttons]
         super().__init__(on_button)
