@@ -6,8 +6,8 @@ from .command import CommandHandler
 
 
 class StartHandler(CommandHandler, ABC):
-    def __init__(self) -> None:
-        super().__init__("start")
+    def __init__(self, reply_text: str | None = None) -> None:
+        super().__init__("start", reply_text)
 
 
 class StartGroupHandler(StartHandler):
